==> rhaf-camel-4.8.5-for-springboot-3.3.10-src.zip: rhaf-camel-spring-boot-4.8.5.CS3-src/narayana-spring-boot-3.2.0-4.8.5/narayana-spring-boot-core/src/main/java/dev/snowdrop/boot/narayana/core/jms/pool/PooledNarayanaConnection.java <==
/*
 * Copyright 2020 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.snowdrop.boot.narayana.core.jms.pool;

import javax.transaction.xa.XAResource;

import jakarta.jms.Connection;
import jakarta.jms.JMSException;
import jakarta.jms.XASession;
import jakarta.transaction.TransactionManager;

import org.messaginghub.pooled.jms.JmsPoolSession;
import org.messaginghub.pooled.jms.pool.PooledXAConnection;

public class PooledNarayanaConnection extends PooledXAConnection {

    private final String name;

    public PooledNarayanaConnection(Connection connection, TransactionManager transactionManager, String name) {
        super(connection, transactionManager);
        this.name = name;
    }

    @Override
    protected XAResource createXaResource(JmsPoolSession session) throws JMSException {
        XAResource xares = ((XASession) session.getInternalSession()).getXAResource();
        if (this.name != null) {
            xares = new NamedXAResource(xares, this.name);
        }
        return xares;
    }

}

==> rhaf-camel-4.14.2-for-springboot-3.5.8-src.zip: rhaf-camel-spring-boot-4.14.2.CS3-src/narayana-spring-boot-3.5.0-4.14.2/narayana-spring-boot-core/src/main/java/dev/snowdrop/boot/narayana/core/jms/pool/PooledNarayanaConnection.java <==
/*
 * Copyright 2020 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.snowdrop.boot.narayana.core.jms.pool;

import javax.transaction.xa.XAResource;

import jakarta.jms.Connection;
import jakarta.jms.JMSException;
import jakarta.transaction.TransactionManager;

import org.messaginghub.pooled.jms.JmsPoolSession;
import org.messaginghub.pooled.jms.pool.PooledXAConnection;

public class PooledNarayanaConnection extends PooledXAConnection {

    private final String name;
    private final boolean lastResource;

    public PooledNarayanaConnection(Connection connection, TransactionManager transactionManager, String name, boolean lastResource) {
        super(connection, transactionManager);
        this.name = name;
        this.lastResource = lastResource;
    }

    @Override
    protected XAResource createXaResource(JmsPoolSession session) throws JMSException {
        XAResource xares = super.createXaResource(session);
        if (this.name != null) {
            if (this.lastResource) {
                xares = new NamedLastXAResource(xares, this.name);
            } else {
                xares = new NamedXAResource(xares, this.name);
            }
        } else if (this.lastResource) {
            xares = new LastXAResource(xares);
        }
        return xares;
    }
}
